@@ -25,3 +25,6 @@ from .get_data import read
 from .get_data import binary_dice_loss
 from .get_data import pseudo_3d_vgg_features
 from .get_data import pseudo_3d_vgg_features_unbiased
+from .get_data import read_srmodel
+from .get_data import simulate_image
+from .get_data import compare_models
