@@ -1096,13 +1096,15 @@ def inference(
     mdl,
     truncation = [0.001,0.999],
     segmentation=None, 
+    target_range=[1,0],
+    match_intensity=True,
     verbose=False):
     if segmentation is None:
         pimg = ants.image_clone( image )
         if truncation is not None:
             pimg = ants.iMath( pimg, 'TruncateIntensity', truncation[0], truncation[1] )
         return antspynet.apply_super_resolution_model_to_image(
-            pimg, mdl, target_range=[0,1], regression_order=None, verbose=verbose
+            pimg, mdl, target_range=target_range, regression_order=None, verbose=verbose
             )
     else:
         pimg = ants.image_clone( image )
@@ -1126,5 +1128,143 @@ def inference(
             segmentation_numbers=mynp,
             dilation_amount=0,
             probability_images=None,
-            probability_labels=None, max_lab_plus_one=True, verbose=verbose)
+            probability_labels=None, 
+            max_lab_plus_one=True, 
+            target_range=target_range,
+            match_intensity=match_intensity,
+            verbose=verbose)
     return None
+
+
+def read_srmodel( srfilename ):
+    """
+    read a sr model with tf and return the model and the shape
+
+    Arguments
+    ---------
+    srfilename : string typically ending in .h5 extension
+
+    Returns
+    -------
+
+    tfmodel, upsampling_factor
+
+    upsampling_factor is [x_up, y_up, z_up, n_channels ] where these are integer values
+
+    Example
+    -------
+    >>> import siq
+    >>> mdl, upshape = siq.read_srmodel( "temp.h5" )
+    """
+    srmdl = tf.keras.models.load_model( srfilename , compile=False )
+    chanindex = 3
+    if len( srmdl.input.shape ) == 5:
+        chanindex = 4
+    nchan = int(srmdl.input.shape[chanindex])
+    if len( srmdl.input.shape ) == 5:
+        outshap = srmdl( np.zeros([1,8,8,8,nchan]) ).shape
+        return srmdl, [int(outshap[1]/8),int(outshap[2]/8),int(outshap[3]/8),nchan]
+    else:
+        outshap = srmdl( np.zeros([1,8,8,nchan]) ).shape
+        return srmdl, [int(outshap[1]/8),int(outshap[2]/8),nchan]
+
+
+
+def simulate_image( shaper=[32,32,32], n_levels=10, multiply=False ):
+    """
+    generate an image of given shape and number of levels
+
+    Arguments
+    ---------
+    shaper : [x,y,z] or [x,y]
+
+    n_levels : int
+
+    multiply : boolean
+
+    Returns
+    -------
+
+    ants.image
+
+    """
+    img = ants.from_numpy( np.random.normal( 0, 1.0, size=shaper ) ) * 0
+    for k in range(n_levels):
+        temp = ants.from_numpy( np.random.normal( 0, 1.0, size=shaper ) )
+        temp = ants.smooth_image( temp, n_levels )
+        temp = ants.threshold_image( temp, "Otsu", 1 )
+        if multiply:
+            temp = temp * k
+        img = img + temp
+    return img
+
+
+def compare_models( model_filenames, img, verbose=False ):
+    """
+    generate a dataframe computing some basic intensity metrics PSNR and SSIM
+    """
+    mydf = pd.DataFrame()
+    for k in range( len( model_filenames ) ):
+        srmdl, upshape = read_srmodel( model_filenames[k] )
+        if verbose:
+            print( model_filenames[k] )
+            print( upshape )
+        tarshape = []
+        inspc = ants.get_spacing(img)
+        for j in range(len(img.shape)):
+            tarshape.append( float(upshape[j]) * inspc[j] )
+        # uses linear interp
+        dimg=ants.resample_image( img, tarshape, use_voxels=False, interp_type=0 )
+        dicesr=0
+        dicenn=0
+        if verbose:
+            print( dimg )
+        if upshape[3] == 2:
+            seghigh = ants.threshold_image( img,"Otsu",2)
+            seglow = ants.resample_image( seghigh, tarshape, use_voxels=False, interp_type=1 )
+            dimgup=inference( dimg, srmdl, segmentation = seglow, verbose=False )
+            dimgupseg = dimgup['super_resolution_segmentation']
+            segimgnn = ants.resample_image_to_target( seglow, dimgupseg, interp_type='nearestNeighbor' )
+            dicenn = ants.label_overlap_measures(seghigh, segimgnn)['MeanOverlap'][0]
+            dicesr = ants.label_overlap_measures(seghigh, dimgupseg)['MeanOverlap'][0]
+            dimgup=dimgup['super_resolution']
+        else:
+            dimgup=inference( dimg, srmdl, verbose=False  )
+        dimglin = ants.resample_image_to_target( dimg, dimgup, interp_type='linear' )
+        imgblock = ants.resample_image_to_target( img, dimgup, interp_type='linear'  )
+        padder = []
+        dimwarning=False
+        for jj in range(img.dimension):
+            padder.append( -2 )
+            if img.shape[jj] != imgblock.shape[jj]:
+                dimwarning=True
+        if dimwarning:
+            print("NOTE: dimensions of downsampled to upsampled image do not match!!!")
+            print("we force them to match but this suggests results may not be reliable.")
+        temp = os.path.basename( model_filenames[k] )
+        temp = re.sub( "siq_default_sisr_", "", temp )
+        temp = re.sub( "_best_mdl.h5", "", temp )
+        if verbose and dimwarning:
+            print( "original img shape" )
+            print( img.shape )
+            print( "resampled img shape" )
+            print( imgblock.shape )
+        a=[]
+        for aa in range(len(upshape)):
+            a.append( str(upshape[aa]) )
+        mydict = {
+            "mdl": temp,
+            "shape":"x".join(a),
+            "PSNR.LIN": antspynet.psnr( imgblock, dimglin ),
+            "PSNR.SR": antspynet.psnr( imgblock, dimgup ),
+            "SSIM.LIN": antspynet.ssim( imgblock, dimglin ),
+            "SSIM.SR": antspynet.ssim( imgblock, dimgup ),
+            "DICE.NN": dicenn,
+            "DICE.SR": dicesr,
+            "dimwarning": dimwarning }
+        if verbose:
+            print( mydict )
+        temp = pd.DataFrame.from_records( [mydict], index=[0] )
+        mydf = pd.concat( [mydf,temp], axis=0 )
+        # end loop
+    return mydf
